import React from 'react';
import type { Tier } from '../App';

type TierCardProps = {
  tier: Tier;
  unlocked: boolean;
  money: number;
  onUnlock: (tier: Tier) => void;
  onBuy: (tier: Tier) => void;
};

const TierCard: React.FC<TierCardProps> = React.memo(({ tier, unlocked, money, onUnlock, onBuy }) => {
  return (
    <div className="bg-white rounded-lg shadow p-4 flex flex-col items-center w-40">
      <div className="text-xl font-semibold mb-1">{tier.name}</div>
      <div className="text-gray-500 text-sm mb-2">Unlock: ${tier.unlockPrice}</div>
      <div className="text-gray-500 text-sm mb-2">Buy: ${tier.buyPrice}</div>
      {!unlocked ? (
        <button
          className="bg-yellow-400 hover:bg-yellow-500 text-white font-bold px-4 py-1 rounded mb-1 disabled:opacity-50"
          disabled={money < tier.unlockPrice}
          onClick={() => onUnlock(tier)}
        >
          Unlock
        </button>
      ) : (
        <button
          className="bg-green-500 hover:bg-green-600 text-white font-bold px-4 py-1 rounded mb-1 disabled:opacity-50"
          disabled={money < tier.buyPrice}
          onClick={() => onBuy(tier)}
        >
          Buy Card
        </button>
      )}
    </div>
  );
});

export default TierCard; 